/**
 * Copyright (c) 2008-2023, MOVES Institute, Naval Postgraduate School (NPS). All rights reserved.
 * This work is provided under a BSD-style open-source license, see project
 * <a href="https://savage.nps.edu/opendis7-java/license.html" target="_blank">license.html</a> and <a href="https://savage.nps.edu/opendis7-java/license.txt" target="_blank">license.txt</a>
 */
// header autogenerated using string template dis7javalicense.txt

// autogenerated using string template disenumpart1.txt

package edu.nps.moves.dis7.enumerations;

import java.nio.ByteBuffer;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

import edu.nps.moves.dis7.pdus.*;

/**
 * This <code>enum</code> type is generated from XML,
 *  UID 582,
 * marshal size 8;
 * DigitalMessageFormat has 10 enumerations total.
 * @see <a href="https://docs.oracle.com/javase/tutorial/java/javaOO/enum.html">Java Tutorials: Enum Types</a>
 * @see java.lang.Enum
 */
public enum DigitalMessageFormat 
{
    // autogenerated using string template disenumfootnotecomment.txt

    /** Link 16 (J-series) message */
    // autogenerated using string template disenumpart2.txt
    LINK_16_J_SERIES_MESSAGE (0, "Link 16 (J-series) message"),
    // autogenerated using string template disenumfootnotecomment.txt

    /** Binary File */
    // autogenerated using string template disenumpart2.txt
    BINARY_FILE (1, "Binary File"),
    // autogenerated using string template disenumfootnotecomment.txt

    /** Variable Message Format (VMF) (K-series) message */
    // autogenerated using string template disenumpart2.txt
    VARIABLE_MESSAGE_FORMAT_VMF_K_SERIES_MESSAGE (2, "Variable Message Format (VMF) (K-series) message"),
    // autogenerated using string template disenumfootnotecomment.txt

    /** National Imagery Transmission Format System (NITFS) */
    // autogenerated using string template disenumpart2.txt
    NATIONAL_IMAGERY_TRANSMISSION_FORMAT_SYSTEM_NITFS (3, "National Imagery Transmission Format System (NITFS)"),
    // autogenerated using string template disenumfootnotecomment.txt

    /** Forwarded Message (FWD MSG) */
    // autogenerated using string template disenumpart2.txt
    FORWARDED_MESSAGE_FWD_MSG (4, "Forwarded Message (FWD MSG)"),
    // autogenerated using string template disenumfootnotecomment.txt

    /** United States Message Text Format (USMTF) */
    // autogenerated using string template disenumpart2.txt
    UNITED_STATES_MESSAGE_TEXT_FORMAT_USMTF (5, "United States Message Text Format (USMTF)"),
    // autogenerated using string template disenumfootnotecomment.txt

    /** DOI-103 */
    // autogenerated using string template disenumpart2.txt
    DOI_103 (6, "DOI-103"),
    // autogenerated using string template disenumfootnotecomment.txt

    /** eXtensible Markup Language (XML) - Message Text Format (MTF) */
    // autogenerated using string template disenumpart2.txt
    EXTENSIBLE_MARKUP_LANGUAGE_XML_MESSAGE_TEXT_FORMAT_MTF (7, "eXtensible Markup Language (XML) - Message Text Format (MTF)"),
    // autogenerated using string template disenumfootnotecomment.txt

    /** eXtensible Markup Language (XML) - Variable Message Format (VMF) */
    // autogenerated using string template disenumpart2.txt
    EXTENSIBLE_MARKUP_LANGUAGE_XML_VARIABLE_MESSAGE_FORMAT_VMF (8, "eXtensible Markup Language (XML) - Variable Message Format (VMF)"),
    // autogenerated using string template disenumfootnotecomment.txt

    /** AFAPD */
    // autogenerated using string template disenumpart2.txt
    AFAPD (16, "AFAPD");

    // autogenerated using string template disenumpart25.txt

    private int value;
    private final String description;

    /** Constructor */
    DigitalMessageFormat(int value, String description)
    {
        this.value = value;
        this.description = description;
    }
    /** Provide enumeration value
      * @return integer value */
    public int getValue()
    {
        return value;
    }

    /** Provide enumeration description
     * @return description
     */
    public String getDescription()
    {
        return description;
    }

    /** bit width for this enumeration
     * @return number of bits wide
     */
    public static int getEnumBitWidth()
    {
      return 8;
    }

    /** 
     * Provide enumeration for a given value
     * @param value integer value of interest
     * @return enumeration corresponding to numeric value
     */
    public static DigitalMessageFormat getEnumForValue(int value)
    {
       for (DigitalMessageFormat nextEnum : DigitalMessageFormat.values())
       {
          if (nextEnum.getValue() == value)
              return nextEnum;
       }
       System.out.flush(); // ensure contiguous console outputs
       System.err.println("No corresponding enumeration found for value " + value + " of enum DigitalMessageFormat");
       System.err.flush(); // ensure contiguous console outputs
       return null;
    }

    // autogenerated using string template disenumpart3_8.txt

    private boolean TRACE = false;

    /** Set tracing on/off for this object 
     * @param value whether tracing is on or off */
    public void setTRACE (boolean value)
    {
        TRACE = value;
    }

    /** Whether tracing is on or off for this object
     * @return whether tracing is on or off */
    public boolean getTRACE ()
    {
        return TRACE;
    }

    /** Marshal value to DataOutputStream
     * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
     * @param dos DataOutputStream for output
     * @throws IOException input-output error */
    public void marshal(DataOutputStream dos) throws IOException
    {
        dos.writeByte(getValue());
    }
    
    /** Marshal value to ByteBuffer
     * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
     * @param byteBuffer ByteBuffer for output
     * @throws IOException input-output error */
    public void marshal(ByteBuffer byteBuffer) throws Exception
    {
        byteBuffer.put((byte)getValue());
    }

    /** Unmarshal value to DataInputStream
     * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
     * @param dis DataInputStream for input
     * @throws Exception unmarshalling input-output error
     * @return enumeration of interest */
    public static DigitalMessageFormat unmarshalEnum (DataInputStream dis) throws Exception
    {
       /* try {
            value = dis.readUnsignedByte();
        }
        catch(IOException ex) {
            showError(ex);
        } */
        
        return getEnumForValue(dis.readByte());
    } 

    /** Unmarshal enumeration value to ByteBuffer
     * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
     * @param byteBuffer ByteBuffer for input
     * @throws Exception unmarshalling input-output error
     * @return enumeration of interest */
    public static DigitalMessageFormat unmarshalEnum(ByteBuffer byteBuffer) throws Exception
    {
        /*
        try {
            value = (int)byteBuffer.get();
        }
        catch(Exception ex) {
            showError(ex);
        }
        */
        return getEnumForValue(byteBuffer.get());
    }

  /**
   * Returns size of this serialized (marshalled) object in bytes
   * @see <a href="https://en.wikipedia.org/wiki/Marshalling_(computer_science)" target="_blank">https://en.wikipedia.org/wiki/Marshalling_(computer_science)</a>
   * @return serialized size in bytes
   */
    public int getMarshalledSize()
    {
        return 1; // 8 bits
    }
  /**
   * Provide name
   * @return  name
   */
    public String getName()
    {
        return name();
    }

    
  /**
   * Provide simple identifier
   * @return class name, value and name
   */
    @Override
    public String toString()
    {
        String padding = new String();
        if (this.getClass().getName().endsWith("DisPduType") && (getValue() < 10))
            padding = "0"; // leading zero for column spacing
        String result = this.getClass().getSimpleName() + " " + padding + getValue() + " " + name();
        if (getTRACE())
            System.out.println ("*** enum " + this.getClass().getSimpleName() + " name=" + name() + ", value=" + getValue() + "; " +
               result); // debug diagnostic
        return result;
    }
}
